function [beta, s, theta, C, invC, lambda] = calibrate_mahal_kriging(Xs,Ys,COV)

	m = length(Xs);

	for i = 1:m,
		for j = 1:m,
			Cv(i,j) = ((Xs(i,:) - Xs(j,:)) * COV * (Xs(i,:) - Xs(j,:))');
		end
	end

	e_min = inf;
	i_min = NaN;
	theta_m = 1;
	for i = -50:4
		theta = 10^i;
		E = energy(theta, Cv, Ys, m);
		if (E <= e_min)
			i_min = i;
			theta_m = theta;
			e_min = E;
		end
	end

	if (isnan(i_min))
		error('Error in the calibration of the Kriging-model')
	end

	e_min = inf;
	for j = 1:20
		theta = 0.2 * 25 * (j/20) * 10^i_min;
		E = energy(theta, Cv, Ys, m);
		if (E <= e_min)
			theta_m = theta;
			e_min = E;
		end
	end

	theta = theta_m;

	C = exp(-theta * Cv);
	invC = pinv(C);
	beta = (ones(1,m) * invC * Ys) / (ones(1,m) * invC * ones(m,1));
	s = ((Ys - beta)' * invC * (Ys - beta)) / m;
	lambda = (Ys - beta)' * invC;


function e = energy(theta, Cv, Y, m)
	C = exp(-theta * Cv);
	if (abs(det(C)) > 1e-60)
		invC = pinv(C);
		beta = (ones(1,m) * invC * Y) / (ones(1,m) * invC * ones(m,1));
		s = ((Y - beta)' * invC * (Y - beta)) / m;
		e = m * log(s) + log(det(C));
	else
		e = Inf;
	end
