function [] = plot_run_statistics(stat)
% [] = plot_run_statistics(stat)
%
%   Plots the statistics of an optimization run
%
% Input:
%   stat           - a struct containing the statistics
%                    of an optimization run
%
% Last modified: Sepetember 9, 2009

	evalcount = stat.evalcount;
	N = length(stat.histx(:,1));

	% Fitness vs evaluations
	if (isfield(stat, 'histf'))
		subplot(2,2,1)
		semilogy(stat.histf(1:stat.evalcount))
		grid on
		ylabel('Fitness')
		xlabel('function evaluations'); 
	end

	% Object variables
	if (isfield(stat, 'histx'))
		subplot(2,2,2);
		plot_run_object_variables_stats(stat);
	end

	% Stepsize
	if (isfield(stat, 'histsigma'))
		subplot(2,2,3)
		semilogy(stat.histsigma')
		grid on
		ylabel('Stepsize')
		xlabel('function evaluations')
	end

	% Standard Deviations in All Coordinates
	if (isfield(stat, 'histstds'))
		subplot(2,2,4);
		semilogy(stat.histstds')
		hold on
		[shx, shxindex] = sort(stat.histstds(:,evalcount)');
		[shx2, shxindex2] = sort(shxindex);
		ls = logspace(log10(min(ylim)), log10(max(ylim)), N);
		plot([evalcount, evalcount], ylim, 'k-')
		xlim([min(xlim), 1.1 * evalcount]);
		plot(repmat([evalcount, max(xlim)], N, 1)', [stat.histstds(:,evalcount)'; ls(shxindex2)])
		for i = 1:length(shx)
			text(max(xlim), ls(i), [' ' num2str(shxindex(i))]);
		end
		ylabel('Standard Deviations in All Coordinates')
		xlabel('function evaluations')
		hold off
		grid on
	end

	% Scaling (All Main Axes)
	if (isfield(stat, 'histdiagD'))
		subplot(2,2,3);
		semilogy(stat.histdiagD')
		hold on
		[shx, shxindex] = sort(stat.histdiagD(:,evalcount)');
		[shx2, shxindex2] = sort(shxindex);
		ls = logspace(log10(min(ylim)), log10(max(ylim)), N);
		plot([evalcount, evalcount], ylim, 'k-')
		xlim([min(xlim), 1.1 * evalcount]);
		plot(repmat([evalcount, max(xlim)], N, 1)', [stat.histdiagD(:,evalcount)'; ls(shxindex2)])
		for i = 1:length(shx)
			text(max(xlim), ls(i), [' ' num2str(shxindex(i))]);
		end
		ylabel('Scaling (All Main Axes)')
		xlabel('function evaluations')
		hold off
		grid on
	end

	% If we have a PSO with mean velocity values
	if (isfield(stat, 'histmeanabsv'))
		subplot(2,2,4)
		plot_run_mean_velocities_stats(stat)
	end
