function [] = test_mahalanobis_kriging(func, sampling_func)
% test_mahalanobis_kriging(func, sample_func)
%                           - an example run of the Mahalanobis distance 
%                             based kriging method
%
% func:                     - the function used for kriging
% sample_func:              - the function used for taking the sampling points

	warning off

	N = 2;
	lb = -2 * ones(N,1);
	ub = 2 * ones(N,1);
	Nkrig = N^6;
	Tests = 100;

	% Select sample points
	Xs = sampling_func(Nkrig, N, lb, ub);
	for i=1:Nkrig
		Ys(i) = feval(func, Xs(i,:));
	end

	% Normalize points for Kriging, map to an interval between 0 and 100
	Xmin = min(Xs);
	Xmax = max(Xs);
	Sk = 100 ./ (Xmax - Xmin);
	Xk = (Xs - repmat(Xmin, Nkrig, 1)) .* repmat(Sk, Nkrig, 1);
	Yk = (Ys' - min(Ys)) * (100 / (max(Ys) - min(Ys)));

	% Construct simple Kriging function f_krig
	[beta, s, theta, C, invC, lambda] = calibrate_kriging(Xk, Yk);
	f_krig = @(X) kriging_estimate(Xk, beta, s, theta, C, invC, lambda, (X - Xmin) .* Sk) / (100 / (max(Ys) - min(Ys))) + min(Ys);

	% Takes a number of test points to compare prediction vs. actual function value
	for j=1:Tests
		x = lb + (ub - lb) .* rand(N,1);
		xk = (x' - Xmin) .* Sk;
		F(j) = feval(func, x');
		Fk(j) = f_krig(x');
	end

	% Plot approximated fitness vs. real-sampled fitness
	subplot(3,1,1)
	plot_func(f_krig, N, lb, ub, 0.1 * ones(N,1));
	hold on
	plot3(Xs(:,1), Xs(:,2), Ys, 'o')
	hold off
	subplot(3,1,2)
	plot_func(func, N, lb, ub, 0.1 * ones(N,1));
	subplot(3,1,3)
	plot(F, Fk, 'o')
	drawnow()

	warning on
